/**
* This code is provided "AS IS", without warranty of any kind.
* This is a sample code, might be not completely error free.
* DevHorizon or author of this code doesn't take any responsibility
* what so ever resulting out of usage of this code.
*/
using System;
using System.Collections.Generic;
using System.Text;
using System.Web.Security;
using System.Collections.Specialized;
using System.Web;

namespace GAEGlobalASAX
{
    public class MinimalMembershipProvider : MembershipProvider
    {
        #region Private Member Variables
        private string _ApplicationName;
        private string _ProviderName;
        #endregion

        #region Property Overrides
        /// <summary>
        /// The name of the application using the membership provider. ApplicationName is used to scope membership data 
        /// so that applications can choose whether to share membership data with other applications. 
        /// This property can be read and written.
        /// </summary>
        public override string ApplicationName
        {
            get
            {

                return _ApplicationName;
            }
            set
            {
                _ApplicationName = value;
            }
        }
        /// <summary>
        /// 
        /// </summary>
        public override string Name
        {
            get
            {
                return _ProviderName;
            }
        }
        #endregion

        #region  Method Overrides

        /// <summary>
        /// Passes on the values of the configuration settings for the provider to the code at runtime
        /// </summary>
        /// <param name="name">Name of Provider</param>
        /// <param name="config">Settings as name-value pairs in an instance of the NameValueCollection class</param>
        public override void Initialize(string name, NameValueCollection config)
        {

            // Check to see if config object is not null
            if (config == null)            
                throw new ArgumentNullException("config");
            
            //Inisitialize Provider Name and Application Name
            _ProviderName = name;
            _ApplicationName = "/";
           
            // Initialize base class
            base.Initialize(name, config);
           
            //TODO: Implement Initialize method spcific for your authentication provider

        }

        /// <summary>
        /// ValidateUser returns true if the user name and password are valid, 
        /// if the user is approved (that is, if MembershipUser.IsApproved is true), 
        /// and if the user isn't currently locked out. Otherwise, it returns false.
        /// </summary>
        /// <param name="username">username</param>
        /// <param name="password">password</param>
        /// <returns></returns>
        public override bool ValidateUser(string username, string password)
        {
            //Check to see if Guest Enabler Feature is installed and activated
            bool showGuestAccount = Utils.IsSiteFeatureActivated(HttpContext.Current, "E748C320-7DFB-43a0-92CF-492B0CE5C5F0");            
            if (username == "Guest" && showGuestAccount) return true;

            //TODO: Implement ValidateUser method
            return false;
        }

        /// <summary>
        /// Returns a MembershipUser object representing the specified user. 
        /// If the user name or user ID is invalid (that is, if it doesn't represent a registered user) 
        /// GetUser returns null.
        /// </summary>
        /// <param name="username">user name</param>
        /// <param name="userIsOnline">a Boolean value indicating whether to update the user's LastActivityDate to show that the user is currently online</param>
        /// <returns></returns>        
        public override MembershipUser GetUser(string username, bool userIsOnline)
        {
            //Check to see if Guest Enabler Feature is installed and activated
            bool showGuestAccount = Utils.IsSiteFeatureActivated(HttpContext.Current, "E748C320-7DFB-43a0-92CF-492B0CE5C5F0");
            if (username == "Guest" && showGuestAccount) return Utils.GetGuestAsMembershipUser(this._ProviderName);  
            
            //TODO: Implement GetUser method
            return null;
           
        }

        /// <summary>
        /// Returns the first registered user name whose e-mail address matches the one supplied.
        /// If it doesn't find a user with a matching e-mail address, GetUserNameByEmail returns an empty string.
        /// </summary>
        /// <param name="email"></param>
        /// <returns>first registered user name whose e-mail address matches the one supplied as email param</returns>
        public override string GetUserNameByEmail(string email)
        {
            //TODO: Implement GetUserNameByEmail method
            return null;
        }

        /// <summary>
        /// Returns a MembershipUserCollection containing MembershipUser objects representing all registered users. 
        /// If there are no registered users, GetAllUsers returns an empty MembershipUserCollection 
        /// The results returned by GetAllUsers are constrained by the pageIndex and pageSize input parameters. 
        /// </summary>
        /// <param name="pageIndex">Identifies which page of results to return. Page indexes are 0-based</param>
        /// <param name="pageSize">Specifies the maximum number of MembershipUser objects to return.</param>
        /// <param name="totalRecords">Holds a count of all registered users.</param>
        /// <returns></returns>
        public override MembershipUserCollection GetAllUsers(int pageIndex, int pageSize, out int totalRecords)
        {
            //TODO: Implement GetAllUsers method
            totalRecords = 1;
            return Utils.GetGuestInMembershipUserCollection(this._ProviderName);

        }

        /// <summary>
        /// Returns a MembershipUserCollection containing MembershipUser objects representing users whose e-mail addresses 
        /// match the emailToMatch input parameter. Wildcard syntax is data source-dependent. 
        /// MembershipUser objects in the MembershipUserCollection are sorted by e-mail address. 
        /// If FindUsersByEmail finds no matching users, it returns an empty MembershipUserCollection.
        /// For an explanation of the pageIndex, pageSize, and totalRecords parameters, see the GetAllUsers method.
        /// </summary>
        /// <param name="emailToMatch">Specifies search criteria for email.</param>
        /// <param name="pageIndex">See the GetAllUsers method.</param>
        /// <param name="pageSize">See the GetAllUsers method.</param>
        /// <param name="totalRecords">See the GetAllUsers method.</param>
        /// <returns></returns>   
        public override MembershipUserCollection FindUsersByEmail(string emailToMatch, int pageIndex, int pageSize, out int totalRecords)
        {

            //TODO: Implement FindUsersByEmail method
            totalRecords = 1;
            return Utils.GetGuestInMembershipUserCollection(this._ProviderName);
           
        }

        /// <summary>
        /// Returns a MembershipUserCollection containing MembershipUser objects representing users whose user names match the usernameToMatch input parameter. 
        /// Wildcard syntax is data source-dependent. MembershipUser objects in the MembershipUserCollection are sorted by user name. 
        /// If FindUsersByName finds no matching users, it returns an empty MembershipUserCollection.
        /// For an explanation of the pageIndex, pageSize, and totalRecords parameters, see the GetAllUsers method.
        /// </summary>
        /// <param name="usernameToMatch">Specifies search criteria for username.</param>
        /// <param name="pageIndex">See the GetAllUsers method.</param>
        /// <param name="pageSize">See the GetAllUsers method.</param>
        /// <param name="totalRecords">See the GetAllUsers method.</param>
        /// <returns></returns>
        public override MembershipUserCollection FindUsersByName(string usernameToMatch, int pageIndex, int pageSize, out int totalRecords)
        {

            //TODO: Implement FindUsersByName method
            totalRecords = 1;
            return Utils.GetGuestInMembershipUserCollection(this._ProviderName);

        }



        #endregion

        #region Property Overrides (Not Supported Yet)
        public override string Description
        {
            get
            {
                throw new NotSupportedException();
            }
        }
        public override bool EnablePasswordRetrieval
        {
            get { throw new NotSupportedException(); }
        }
        public override bool EnablePasswordReset
        {
            get { throw new NotSupportedException(); }
        }
        public override int MaxInvalidPasswordAttempts
        {
            get { throw new NotSupportedException(); }
        }
        public override int MinRequiredNonAlphanumericCharacters
        {
            get { throw new NotSupportedException(); }
        }
        public override int MinRequiredPasswordLength
        {
            get { throw new NotSupportedException(); }
        }
        public override int PasswordAttemptWindow
        {
            get { throw new NotSupportedException(); }
        }
        public override MembershipPasswordFormat PasswordFormat
        {
            get { throw new NotSupportedException(); }
        }
        public override string PasswordStrengthRegularExpression
        {
            get { throw new NotSupportedException(); }
        }
        public override bool RequiresQuestionAndAnswer
        {
            get { throw new NotSupportedException(); }
        }
        public override bool RequiresUniqueEmail
        {
            get { throw new NotSupportedException(); }
        }
        #endregion

        #region Method Overrides (Not Supported Yet)
        public override int GetNumberOfUsersOnline()
        {
            throw new NotSupportedException();
        }
        public override bool ChangePassword(string username, string oldPassword, string newPassword)
        {
            throw new NotSupportedException();
        }
        public override bool ChangePasswordQuestionAndAnswer(string username, string password, string newPasswordQuestion, string newPasswordAnswer)
        {
            throw new NotSupportedException();
        }
        public override MembershipUser CreateUser(string username, string password, string email, string passwordQuestion, string passwordAnswer, bool isApproved, object providerUserKey, out MembershipCreateStatus status)
        {
            throw new NotSupportedException();
        }
        public override bool DeleteUser(string username, bool deleteAllRelatedData)
        {
            throw new NotSupportedException();
        }
        public override MembershipUser GetUser(object providerUserKey, bool userIsOnline)
        {
            throw new NotSupportedException();
        }
        public override string GetPassword(string username, string answer)
        {
            throw new NotSupportedException();
        }
        public override string ResetPassword(string username, string answer)
        {
            throw new NotSupportedException();
        }
        public override bool UnlockUser(string userName)
        {
            throw new NotSupportedException();
        }
        public override void UpdateUser(MembershipUser user)
        {
            throw new NotSupportedException();
        }
        protected override byte[] DecryptPassword(byte[] encodedPassword)
        {
            throw new NotSupportedException();
        }
        protected override byte[] EncryptPassword(byte[] password)
        {
            throw new NotSupportedException();
        }
        protected override void OnValidatingPassword(ValidatePasswordEventArgs e)
        {
            throw new NotSupportedException();
        }
        #endregion


    }
}
