/**
* This code is provided "AS IS", without warranty of any kind.
* This is a sample code, might be not completely error free.
* DevHorizon or author of this code doesn't take any responsibility
* what so ever resulting out of usage of this code.
*/
using System;
using System.Collections.Generic;
using System.Text;
using System.Web;
using Microsoft.SharePoint;
using System.Web.Security;
using Microsoft.SharePoint.Administration;
using System.Web.Configuration;

namespace GAEGlobalASAX
{
    public class Utils
    {
        public static bool IsSiteFeatureActivated(HttpContext context, string featureID)
        {
            SPWebApplication app = SPWebApplication.Lookup(new Uri(context.Request.Url.AbsoluteUri));
            using (SPSite site = app.Sites[0])
            {
                SPFeature returnsiteFeatures = site.Features[new Guid(featureID)];
                return (returnsiteFeatures != null ? true : false);
            }
        }
        public static bool IsSiteFeatureActivated(SPSite siteContext, string featureID)
        {
            SPFeature returnsiteFeatures = siteContext.Features[new Guid(featureID)];
            return (returnsiteFeatures != null ? true : false);
        }     
        public static MembershipUser GetGuestAsMembershipUser(string providerName)
        {
            MembershipUser user = new MembershipUser(providerName, "Guest",
                                                    "Guest", string.Empty, string.Empty, string.Empty, true, false,
                                                    DateTime.MinValue, DateTime.MinValue, DateTime.MinValue,
                                                    DateTime.MinValue, DateTime.MinValue);

            return user;
        }

        public static MembershipUserCollection GetGuestInMembershipUserCollection(string providerName)
        {
            MembershipUserCollection uc = new MembershipUserCollection();
            uc.Add(GetGuestAsMembershipUser(providerName));
            return uc;
        }        

        public static string GetMembershipProvider(HttpContext context)
        {
            SPWebApplication app = SPWebApplication.Lookup(new Uri(context.Request.Url.AbsoluteUri));
            SPIisSettings settings = app.IisSettings[SPUrlZone.Default];
            return settings.MembershipProvider;
        }
        public static string GetMembershipProvider(SPSite site)
        {
            // get membership provider of whichever zone in the web app is fba enabled 
            SPIisSettings settings = GetFBAIisSettings(site);
            return settings.MembershipProvider;
        }
        public static SPIisSettings GetFBAIisSettings(SPSite site)
        {
            SPIisSettings settings = null;

            // try and get FBA IIS settings from current site zone
            try
            {
                settings = site.WebApplication.IisSettings[site.Zone];
                if (settings.AuthenticationMode == AuthenticationMode.Forms)
                    return settings;
            }
            catch
            {
                // expecting errors here so do nothing                 
            }

            // check each zone type for an FBA enabled IIS site
            foreach (SPUrlZone zone in Enum.GetValues(typeof(SPUrlZone)))
            {
                try
                {
                    settings = site.WebApplication.IisSettings[(SPUrlZone)zone];
                    if (settings.AuthenticationMode == AuthenticationMode.Forms)
                        return settings;
                }
                catch
                {
                    // expecting errors here so do nothing                 
                }
            }

            // return null if FBA not enabled
            return null;
        }
        public static bool IsWebAppFBAEnabled(SPSite site)
        {
            SPIisSettings settings = site.WebApplication.IisSettings[site.Zone];
            return (settings.AuthenticationMode == AuthenticationMode.Forms);
        }

    }
}
